@@ -1,6 +1,6 @@
 /* A program to put stress on a POSIX system (stress).
  *
- * Copyright (C) 2001,2002,2003,2004,2005
+ * Copyright (C) 2001,2002,2003,2004,2005,2006,2007
  * Amos Waterland <apw@rossby.metr.ou.edu>
  *
  * This program is free software; you can redistribute it and/or modify it
@@ -481,7 +481,8 @@ int
 hogvm (long long bytes, long long stride, long long hang, int keep)
 {
   long long i;
-  char *ptr;
+  char *ptr = 0;
+  char c;
   int do_malloc = 1;
 
   while (1)
@@ -514,6 +515,16 @@ hogvm (long long bytes, long long stride, long long hang, int keep)
           sleep (hang);
         }
 
+      for (i = 0; i < bytes; i += stride)
+	{
+           c = ptr[i];
+	   if (c != 'Z')
+            {
+              err (stderr, "memory corruption at: %p\n", ptr + i);
+              return 1;
+            }
+	}
+
       if (do_malloc)
         {
           free (ptr);
@@ -578,7 +589,7 @@ hoghdd (long long bytes, int clean)
       dbg (stdout, "slow writing to %s\n", name);
       for (; bytes == 0 || j < bytes - 1; j++)
         {
-          if (write (fd, "Z", 1) == -1)
+          if (write (fd, &buff[j % chunk], 1) == -1)
             {
               err (stderr, "write failed: %s\n", strerror (errno));
               return 1;
